15.129. cdist-type__ssh_authorized_key(7) — cdist 4.10.4 documentation

# 15.129. cdist-type__ssh_authorized_key(7)

## 15.129.1. NAME

cdist-type__ssh_authorized_key - Manage a single ssh authorized key entry

## 15.129.2. DESCRIPTION

Manage a single authorized key entry in an authorized_key file. This type was created to be used by the __ssh_authorized_keys type.

## 15.129.3. REQUIRED PARAMETERS

file
  the authorized_keys file to which the given key should be added
key
  a string containing the ssh keytype, base 64 encoded key and optional trailing comment which shall be added to the given authorized_keys file.

## 15.129.4. OPTIONAL PARAMETERS

comment
  explicit comment instead of the one which may be trailing the given key
option
  an option to set for this authorized_key entry. Can be specified multiple times. See sshd(8) for available options.
state
  if the given keys should be 'present' or 'absent', defaults to 'present'.

## 15.129.5. MESSAGES

added to file (entry)
  The key entry (with optional comment) was added to file.
removed from file (entry)
  The key entry (with optional comment) was removed from file.

## 15.129.6. EXAMPLES

    __ssh_authorized_key some-id \
       --file "/home/user/.ssh/autorized_keys" \
       --key "$(cat ~/.ssh/id_rsa.pub)"

    __ssh_authorized_key some-id \
       --file "/home/user/.ssh/autorized_keys" \
       --key "$(cat ~/.ssh/id_rsa.pub)" \
       --option 'command="/path/to/script"' \
       --option 'environment="FOO=bar"' \
       --comment 'one to rule them all'

## 15.129.7. SEE ALSO

cdist__ssh_authorized_keys(7), sshd(8)

## 15.129.8. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 15.129.9. COPYING

Copyright (C) 2014 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.